@@ -141,7 +141,7 @@ class WaldurClient(object):
         Configuration = "configuration"
         Customers = "customers"
         Flavor = "openstacktenant-flavors"
-        FloatingIP = "openstacktenant-floating-ips"
+        FloatingIP = "openstack-floating-ips"
         FreeIPAProfiles = "freeipa-profiles"
         Image = "openstacktenant-images"
         Instance = "openstacktenant-instances"
@@ -171,7 +171,6 @@ class WaldurClient(object):
         SlurmAllocationUserUsages = "slurm-allocation-user-usages"
         Snapshot = "openstacktenant-snapshots"
         SshKey = "keys"
-        TenantSubnet = "openstacktenant-subnets"
         Subnet = "openstack-subnets"
         Tenant = "openstack-tenants"
         TenantSecurityGroup = "openstack-security-groups"
@@ -507,7 +506,7 @@ class WaldurClient(object):
         return self._query_resource(self.Endpoints.FloatingIP, {"address": address})
 
     def _get_subnet(self, identifier):
-        return self._get_resource(self.Endpoints.TenantSubnet, identifier)
+        return self._get_resource(self.Endpoints.Subnet, identifier)
 
     def _get_tenant_subnet_by_uuid(self, uuid):
         query = {
@@ -743,15 +742,15 @@ class WaldurClient(object):
         if unlink_subnet:
             self.unlink_subnet(uuid)
 
-        return self._update_resource(self.Endpoints.TenantSubnet, uuid, payload)
+        return self._update_resource(self.Endpoints.Subnet, uuid, payload)
 
     def list_subnets(self, filters=None):
-        endpoint = self._build_url(self.Endpoints.TenantSubnet)
+        endpoint = self._build_url(self.Endpoints.Subnet)
         return self._query_resource_list(endpoint, filters)
 
     def list_tenant_subnets(self, tenant):
         query = {"tenant": tenant}
-        return self._query_resource_list(self.Endpoints.TenantSubnet, query)
+        return self._query_resource_list(self.Endpoints.Subnet, query)
 
     def list_service_settings(self, filters=None):
         endpoint = self._build_url(self.Endpoints.Provider)
@@ -813,7 +812,7 @@ class WaldurClient(object):
         return subnet
 
     def delete_subnet(self, uuid):
-        return self._delete_resource(self.Endpoints.TenantSubnet, uuid)
+        return self._delete_resource(self.Endpoints.Subnet, uuid)
 
     def update_security_group_description(self, security_group, description):
         payload = {
@@ -1215,7 +1214,7 @@ class WaldurClient(object):
 
         return resource
 
-    def update_instance_internal_ips_set(
+    def update_instance_ports(
         self, instance_uuid, subnet_set, wait=True, interval=10, timeout=600
     ):
         """
@@ -1228,15 +1227,15 @@ class WaldurClient(object):
         :param timeout: a maximum amount of time to wait for operation completion.
         """
 
-        payload = {"internal_ips_set": []}
+        payload = {"ports": []}
         for subnet in subnet_set:
             subnet = self._get_subnet(subnet)
-            payload["internal_ips_set"].append({"subnet": subnet["url"]})
+            payload["ports"].append({"subnet": subnet["url"]})
 
         self._execute_resource_action(
             endpoint=self.Endpoints.Instance,
             uuid=instance_uuid,
-            action="update_internal_ips_set",
+            action="update_ports",
             json=payload,
         )
         if wait:
@@ -1533,7 +1532,7 @@ class WaldurClient(object):
             "flavor": flavor["url"],
             "image": image["url"],
             "system_volume_size": system_volume_size * 1024,
-            "internal_ips_set": subnets,
+            "ports": subnets,
             "floating_ips": floating_ips,
         }
 
